@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -36,7 +36,7 @@ namespace vmime
 
 
 // static
-const bool attachmentHelper::isBodyPartAnAttachment(ref <const bodyPart> part)
+bool attachmentHelper::isBodyPartAnAttachment(ref <const bodyPart> part)
 {
 	try
 	{
@@ -50,10 +50,14 @@ const bool attachmentHelper::isBodyPartAnAttachment(ref <const bodyPart> part)
 			return true;
 
 		// If the Content-Disposition is 'inline' and there is no
-		// Content-Id or Content-Location field, it is an attachment
+		// Content-Id or Content-Location field, it may be an attachment
 		if (!part->getHeader()->hasField(vmime::fields::CONTENT_ID) &&
 		    !part->getHeader()->hasField(vmime::fields::CONTENT_LOCATION))
 		{
+			// If this is the root part, it might not be an attachment
+			if (part->getParentPart() == NULL)
+				return false;
+
 			return true;
 		}
 	}
