@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -104,13 +104,13 @@ charset& charset::operator=(const charset& other)
 }
 
 
-const bool charset::operator==(const charset& value) const
+bool charset::operator==(const charset& value) const
 {
 	return (utility::stringUtils::isStringEqualNoCase(m_name, value.m_name));
 }
 
 
-const bool charset::operator!=(const charset& value) const
+bool charset::operator!=(const charset& value) const
 {
 	return !(*this == value);
 }
