@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -150,7 +150,7 @@ void disposition::removeAllModifiers()
 }
 
 
-const bool disposition::hasModifier(const string& modifier) const
+bool disposition::hasModifier(const string& modifier) const
 {
 	const string modifierLC = utility::stringUtils::toLower(modifier);
 
