@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -284,7 +284,7 @@ void headerField::setName(const string& name)
 }
 
 
-const bool headerField::isCustom() const
+bool headerField::isCustom() const
 {
 	return (m_name.length() > 2 && m_name[0] == 'X' && m_name[1] == '-');
 }
