@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -291,7 +291,7 @@ ref <attachment> messageBuilder::getAttachmentAt(const int pos)
 }
 
 
-const int messageBuilder::getAttachmentCount() const
+int messageBuilder::getAttachmentCount() const
 {
 	return (m_attach.size());
 }
