@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -198,13 +198,13 @@ void messageIdSequence::removeAllMessageIds()
 }
 
 
-const int messageIdSequence::getMessageIdCount() const
+int messageIdSequence::getMessageIdCount() const
 {
 	return (m_list.size());
 }
 
 
-const bool messageIdSequence::isEmpty() const
+bool messageIdSequence::isEmpty() const
 {
 	return (m_list.empty());
 }
