@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -279,7 +279,7 @@ const std::vector <ref <const attachment> > messageParser::getAttachmentList() c
 }
 
 
-const int messageParser::getAttachmentCount() const
+int messageParser::getAttachmentCount() const
 {
 	return (m_attach.size());
 }
@@ -307,7 +307,7 @@ const std::vector <ref <const textPart> > messageParser::getTextPartList() const
 }
 
 
-const int messageParser::getTextPartCount() const
+int messageParser::getTextPartCount() const
 {
 	return (m_textParts.size());
 }
