@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -40,7 +40,7 @@ const string defaultConnectionInfos::getHost() const
 }
 
 
-const port_t defaultConnectionInfos::getPort() const
+port_t defaultConnectionInfos::getPort() const
 {
 	return m_port;
 }
