@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -12,9 +12,13 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License along along
-// with this program; if not, write to the Free Software Foundation, Inc., Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
 #include "vmime/net/events.hpp"
@@ -42,7 +46,7 @@ messageCountEvent::messageCountEvent
 
 
 ref <folder> messageCountEvent::getFolder() const { return (m_folder); }
-const messageCountEvent::Types messageCountEvent::getType() const { return (m_type); }
+messageCountEvent::Types messageCountEvent::getType() const { return (m_type); }
 const std::vector <int>& messageCountEvent::getNumbers() const { return (m_nums); }
 
 
@@ -69,7 +73,7 @@ messageChangedEvent::messageChangedEvent
 
 
 ref <folder> messageChangedEvent::getFolder() const { return (m_folder); }
-const messageChangedEvent::Types messageChangedEvent::getType() const { return (m_type); }
+messageChangedEvent::Types messageChangedEvent::getType() const { return (m_type); }
 const std::vector <int>& messageChangedEvent::getNumbers() const { return (m_nums); }
 
 
@@ -92,7 +96,7 @@ folderEvent::folderEvent
 
 
 ref <folder> folderEvent::getFolder() const { return (m_folder); }
-const folderEvent::Types folderEvent::getType() const { return (m_type); }
+folderEvent::Types folderEvent::getType() const { return (m_type); }
 
 
 void folderEvent::dispatch(folderListener* listener) const
