@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -12,9 +12,13 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License along along
-// with this program; if not, write to the Free Software Foundation, Inc., Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
 #include "vmime/net/imap/IMAPParser.hpp"
@@ -26,6 +30,7 @@
 
 #include <sstream>
 #include <iterator>
+#include <typeinfo>
 
 
 namespace vmime {
@@ -56,8 +61,8 @@ public:
 	ref <const IMAPpart> getParent() const { return m_parent.acquire(); }
 
 	const mediaType& getType() const { return (m_mediaType); }
-	const int getSize() const { return (m_size); }
-	const int getNumber() const { return (m_number); }
+	int getSize() const { return (m_size); }
+	int getNumber() const { return (m_number); }
 
 	ref <const header> getHeader() const
 	{
@@ -145,7 +150,7 @@ public:
 		return m_parts[x];
 	}
 
-	const int getPartCount() const
+	int getPartCount() const
 	{
 		return m_parts.size();
 	}
@@ -295,7 +300,7 @@ void IMAPMessage::onFolderClosed()
 }
 
 
-const int IMAPMessage::getNumber() const
+int IMAPMessage::getNumber() const
 {
 	return (m_num);
 }
@@ -307,7 +312,7 @@ const message::uid IMAPMessage::getUniqueId() const
 }
 
 
-const int IMAPMessage::getSize() const
+int IMAPMessage::getSize() const
 {
 	if (m_size == -1)
 		throw exceptions::unfetched_object();
@@ -316,13 +321,13 @@ const int IMAPMessage::getSize() const
 }
 
 
-const bool IMAPMessage::isExpunged() const
+bool IMAPMessage::isExpunged() const
 {
 	return (m_expunged);
 }
 
 
-const int IMAPMessage::getFlags() const
+int IMAPMessage::getFlags() const
 {
 	if (m_flags == FLAG_UNDEFINED)
 		throw exceptions::unfetched_object();
