@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -12,9 +12,13 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License along along
-// with this program; if not, write to the Free Software Foundation, Inc., Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
 #include "vmime/net/maildir/maildirFolder.hpp"
@@ -22,6 +26,7 @@
 #include "vmime/net/maildir/maildirStore.hpp"
 #include "vmime/net/maildir/maildirMessage.hpp"
 #include "vmime/net/maildir/maildirUtils.hpp"
+#include "vmime/net/maildir/maildirFormat.hpp"
 
 #include "vmime/utility/smartPtr.hpp"
 
@@ -69,7 +74,7 @@ void maildirFolder::onStoreDisconnected()
 }
 
 
-const int maildirFolder::getMode() const
+int maildirFolder::getMode() const
 {
 	if (!isOpen())
 		throw exceptions::illegal_state("Folder not open");
@@ -78,7 +83,7 @@ const int maildirFolder::getMode() const
 }
 
 
-const int maildirFolder::getType()
+int maildirFolder::getType()
 {
 	if (m_path.isEmpty())
 		return (TYPE_CONTAINS_FOLDERS);
@@ -87,27 +92,12 @@ const int maildirFolder::getType()
 }
 
 
-const int maildirFolder::getFlags()
+int maildirFolder::getFlags()
 {
 	int flags = 0;
 
-	utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
-
-	ref <utility::file> rootDir = fsf->create
-		(maildirUtils::getFolderFSPath(m_store.acquire(), m_path, maildirUtils::FOLDER_PATH_CONTAINER));
-
-	ref <utility::fileIterator> it = rootDir->getFiles();
-
-	while (it->hasMoreElements())
-	{
-		ref <utility::file> file = it->nextElement();
-
-		if (maildirUtils::isSubfolderDirectory(*file))
-		{
-			flags |= FLAG_CHILDREN; // Contains at least one sub-folder
-			break;
-		}
-	}
+	if (m_store.acquire()->getFormat()->folderHasSubfolders(m_path))
+		flags |= FLAG_CHILDREN; // Contains at least one sub-folder
 
 	return (flags);
 }
@@ -207,26 +197,7 @@ void maildirFolder::create(const int /* type */)
 	// Create directory on file system
 	try
 	{
-		utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
-
-		if (!fsf->isValidPath(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_ROOT)))
-			throw exceptions::invalid_folder_name();
-
-		ref <utility::file> rootDir = fsf->create
-			(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_ROOT));
-
-		ref <utility::file> newDir = fsf->create
-			(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_NEW));
-		ref <utility::file> tmpDir = fsf->create
-			(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_TMP));
-		ref <utility::file> curDir = fsf->create
-			(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_CUR));
-
-		rootDir->createDirectory(true);
-
-		newDir->createDirectory(false);
-		tmpDir->createDirectory(false);
-		curDir->createDirectory(false);
+		store->getFormat()->createFolder(m_path);
 	}
 	catch (exceptions::filesystem_exception& e)
 	{
@@ -251,18 +222,10 @@ void maildirFolder::destroy()
 	else if (isOpen())
 		throw exceptions::illegal_state("Folder is open");
 
-	// Delete 'folder' and '.folder.directory' directories
-	utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
-
-	ref <utility::file> rootDir = fsf->create
-		(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_ROOT));
-	ref <utility::file> contDir = fsf->create
-		(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_CONTAINER));
-
+	// Delete folder
 	try
 	{
-		maildirUtils::recursiveFSDelete(rootDir);
-		maildirUtils::recursiveFSDelete(contDir);
+		store->getFormat()->destroyFolder(m_path);
 	}
 	catch (std::exception&)
 	{
@@ -278,30 +241,15 @@ void maildirFolder::destroy()
 }
 
 
-const bool maildirFolder::exists()
+bool maildirFolder::exists()
 {
 	ref <maildirStore> store = m_store.acquire();
 
-	utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
-
-	ref <utility::file> rootDir = fsf->create
-		(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_ROOT));
-
-	ref <utility::file> newDir = fsf->create
-		(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_NEW));
-	ref <utility::file> tmpDir = fsf->create
-		(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_TMP));
-	ref <utility::file> curDir = fsf->create
-		(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_CUR));
-
-	return (rootDir->exists() && rootDir->isDirectory() &&
-	        newDir->exists() && newDir->isDirectory() &&
-	        tmpDir->exists() && tmpDir->isDirectory() &&
-	        curDir->exists() && curDir->isDirectory());
+	return store->getFormat()->folderExists(m_path);
 }
 
 
-const bool maildirFolder::isOpen() const
+bool maildirFolder::isOpen() const
 {
 	return (m_open);
 }
@@ -318,12 +266,12 @@ void maildirFolder::scanFolder()
 
 		utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
 
-		utility::file::path newDirPath = maildirUtils::getFolderFSPath
-			(store, m_path, maildirUtils::FOLDER_PATH_NEW);
+		utility::file::path newDirPath = store->getFormat()->folderPathToFileSystemPath
+			(m_path, maildirFormat::NEW_DIRECTORY);
 		ref <utility::file> newDir = fsf->create(newDirPath);
 
-		utility::file::path curDirPath = maildirUtils::getFolderFSPath
-			(store, m_path, maildirUtils::FOLDER_PATH_CUR);
+		utility::file::path curDirPath = store->getFormat()->folderPathToFileSystemPath
+			(m_path, maildirFormat::CUR_DIRECTORY);
 		ref <utility::file> curDir = fsf->create(curDirPath);
 
 		// New received messages (new/)
@@ -493,7 +441,7 @@ std::vector <ref <message> > maildirFolder::getMessages(const std::vector <int>&
 }
 
 
-const int maildirFolder::getMessageCount()
+int maildirFolder::getMessageCount()
 {
 	return (m_messageCount);
 }
@@ -531,39 +479,17 @@ void maildirFolder::listFolders(std::vector <ref <folder> >& list, const bool re
 
 	try
 	{
-		utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
+		std::vector <folder::path> pathList =
+			store->getFormat()->listFolders(m_path, recursive);
 
-		ref <utility::file> rootDir = fsf->create
-			(maildirUtils::getFolderFSPath(store, m_path,
-				m_path.isEmpty() ? maildirUtils::FOLDER_PATH_ROOT
-				                 : maildirUtils::FOLDER_PATH_CONTAINER));
+		list.reserve(pathList.size());
 
-		if (rootDir->exists())
+		for (unsigned int i = 0, n = pathList.size() ; i < n ; ++i)
 		{
-			ref <utility::fileIterator> it = rootDir->getFiles();
+			ref <maildirFolder> subFolder =
+				vmime::create <maildirFolder>(pathList[i], store);
 
-			while (it->hasMoreElements())
-			{
-				ref <utility::file> file = it->nextElement();
-
-				if (maildirUtils::isSubfolderDirectory(*file))
-				{
-					const utility::path subPath =
-						m_path / file->getFullPath().getLastComponent();
-
-					ref <maildirFolder> subFolder =
-						vmime::create <maildirFolder>(subPath, store);
-
-					list.push_back(subFolder);
-
-					if (recursive)
-						subFolder->listFolders(list, true);
-				}
-			}
-		}
-		else
-		{
-			// No sub-folder
+			list.push_back(subFolder);
 		}
 	}
 	catch (exceptions::filesystem_exception& e)
@@ -585,50 +511,12 @@ void maildirFolder::rename(const folder::path& newPath)
 		throw exceptions::invalid_folder_name();
 
 	// Rename the directory on the file system
-	utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
-
-	ref <utility::file> rootDir = fsf->create
-		(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_ROOT));
-	ref <utility::file> contDir = fsf->create
-		(maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_CONTAINER));
-
 	try
 	{
-		const utility::file::path newRootPath =
-			maildirUtils::getFolderFSPath(store, newPath, maildirUtils::FOLDER_PATH_ROOT);
-		const utility::file::path newContPath =
-			maildirUtils::getFolderFSPath(store, newPath, maildirUtils::FOLDER_PATH_CONTAINER);
-
-		rootDir->rename(newRootPath);
-
-		// Container directory may not exist, so ignore error when trying to rename it
-		try
-		{
-			contDir->rename(newContPath);
-		}
-		catch (exceptions::filesystem_exception& e)
-		{
-			// Ignore
-		}
+		store->getFormat()->renameFolder(m_path, newPath);
 	}
-	catch (exceptions::filesystem_exception& e)
+	catch (vmime::exception& e)
 	{
-		// Revert to old location
-		const utility::file::path rootPath =
-			maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_ROOT);
-		const utility::file::path contPath =
-			maildirUtils::getFolderFSPath(store, m_path, maildirUtils::FOLDER_PATH_CONTAINER);
-
-		try
-		{
-			rootDir->rename(rootPath);
-			contDir->rename(contPath);
-		}
-		catch (exceptions::filesystem_exception& e)
-		{
-			// Ignore
-		}
-
 		throw exceptions::command_error("RENAME", "", "", e);
 	}
 
@@ -874,8 +762,8 @@ void maildirFolder::setMessageFlagsImpl
 
 	utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
 
-	utility::file::path curDirPath = maildirUtils::getFolderFSPath
-		(store, m_path, maildirUtils::FOLDER_PATH_CUR);
+	utility::file::path curDirPath = store->getFormat()->
+		folderPathToFileSystemPath(m_path, maildirFormat::CUR_DIRECTORY);
 
 	for (std::vector <int>::const_iterator it =
 	     nums.begin() ; it != nums.end() ; ++it)
@@ -946,10 +834,10 @@ void maildirFolder::addMessage(utility::inputStream& is, const int size,
 
 	utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
 
-	utility::file::path tmpDirPath = maildirUtils::getFolderFSPath
-		(store, m_path, maildirUtils::FOLDER_PATH_TMP);
-	utility::file::path curDirPath = maildirUtils::getFolderFSPath
-		(store, m_path, maildirUtils::FOLDER_PATH_CUR);
+	utility::file::path tmpDirPath = store->getFormat()->
+		folderPathToFileSystemPath(m_path, maildirFormat::TMP_DIRECTORY);
+	utility::file::path curDirPath = store->getFormat()->
+		folderPathToFileSystemPath(m_path, maildirFormat::CUR_DIRECTORY);
 
 	const utility::file::path::component filename =
 		maildirUtils::buildFilename(maildirUtils::generateId(),
@@ -1165,13 +1053,13 @@ void maildirFolder::copyMessagesImpl(const folder::path& dest, const std::vector
 
 	utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
 
-	utility::file::path curDirPath = maildirUtils::getFolderFSPath
-		(store, m_path, maildirUtils::FOLDER_PATH_CUR);
+	utility::file::path curDirPath = store->getFormat()->folderPathToFileSystemPath
+		(m_path, maildirFormat::CUR_DIRECTORY);
 
-	utility::file::path destCurDirPath = maildirUtils::getFolderFSPath
-		(store, dest, maildirUtils::FOLDER_PATH_CUR);
-	utility::file::path destTmpDirPath = maildirUtils::getFolderFSPath
-		(store, dest, maildirUtils::FOLDER_PATH_TMP);
+	utility::file::path destCurDirPath = store->getFormat()->
+		folderPathToFileSystemPath(dest, maildirFormat::CUR_DIRECTORY);
+	utility::file::path destTmpDirPath = store->getFormat()->
+		folderPathToFileSystemPath(dest, maildirFormat::TMP_DIRECTORY);
 
 	// Create destination directories
 	try
@@ -1307,8 +1195,8 @@ void maildirFolder::expunge()
 
 	utility::fileSystemFactory* fsf = platform::getHandler()->getFileSystemFactory();
 
-	utility::file::path curDirPath = maildirUtils::getFolderFSPath
-		(store, m_path, maildirUtils::FOLDER_PATH_CUR);
+	utility::file::path curDirPath = store->getFormat()->
+		folderPathToFileSystemPath(m_path, maildirFormat::CUR_DIRECTORY);
 
 	std::vector <int> nums;
 	int unreadCount = 0;
@@ -1451,7 +1339,7 @@ void maildirFolder::fetchMessage(ref <message> msg, const int options)
 }
 
 
-const int maildirFolder::getFetchCapabilities() const
+int maildirFolder::getFetchCapabilities() const
 {
 	return (FETCH_ENVELOPE | FETCH_STRUCTURE | FETCH_CONTENT_INFO |
 	        FETCH_FLAGS | FETCH_SIZE | FETCH_FULL_HEADER | FETCH_UID |
@@ -1461,8 +1349,8 @@ const int maildirFolder::getFetchCapabilities() const
 
 const utility::file::path maildirFolder::getMessageFSPath(const int number) const
 {
-	utility::file::path curDirPath = maildirUtils::getFolderFSPath
-		(m_store.acquire(), m_path, maildirUtils::FOLDER_PATH_CUR);
+	utility::file::path curDirPath = m_store.acquire()->getFormat()->
+		folderPathToFileSystemPath(m_path, maildirFormat::CUR_DIRECTORY);
 
 	return (curDirPath / m_messageInfos[number - 1].path);
 }
