@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -12,9 +12,13 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License along along
-// with this program; if not, write to the Free Software Foundation, Inc., Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
 #include "vmime/net/pop3/POP3Message.hpp"
@@ -51,7 +55,7 @@ void POP3Message::onFolderClosed()
 }
 
 
-const int POP3Message::getNumber() const
+int POP3Message::getNumber() const
 {
 	return (m_num);
 }
@@ -63,7 +67,7 @@ const message::uid POP3Message::getUniqueId() const
 }
 
 
-const int POP3Message::getSize() const
+int POP3Message::getSize() const
 {
 	if (m_size == -1)
 		throw exceptions::unfetched_object();
@@ -72,13 +76,13 @@ const int POP3Message::getSize() const
 }
 
 
-const bool POP3Message::isExpunged() const
+bool POP3Message::isExpunged() const
 {
 	return (false);
 }
 
 
-const int POP3Message::getFlags() const
+int POP3Message::getFlags() const
 {
 	int flags = FLAG_RECENT;
 
