@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -12,9 +12,13 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License along along
-// with this program; if not, write to the Free Software Foundation, Inc., Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
 #include "vmime/net/sendmail/sendmailTransport.hpp"
@@ -88,13 +92,13 @@ void sendmailTransport::connect()
 }
 
 
-const bool sendmailTransport::isConnected() const
+bool sendmailTransport::isConnected() const
 {
 	return (m_connected);
 }
 
 
-const bool sendmailTransport::isSecuredConnection() const
+bool sendmailTransport::isSecuredConnection() const
 {
 	return false;
 }
@@ -102,7 +106,7 @@ const bool sendmailTransport::isSecuredConnection() const
 
 ref <connectionInfos> sendmailTransport::getConnectionInfos() const
 {
-	return vmime::create <defaultConnectionInfos>("localhost", 0);
+	return vmime::create <defaultConnectionInfos>("localhost", static_cast <port_t>(0));
 }
 
 
