@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -12,9 +12,13 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License along along
-// with this program; if not, write to the Free Software Foundation, Inc., Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
 #include "vmime/net/transport.hpp"
@@ -94,6 +98,16 @@ void transport::send(ref <vmime::message> msg, utility::progressListener* progre
 	}
 	catch (exceptions::no_such_field&) { }
 
+	// Remove BCC headers from the message we're about to send, as required by the RFC.
+	// Some SMTP server automatically strip this header (Postfix, qmail), and others
+	// have an option for this (Exim).
+	try
+	{
+		ref <headerField> bcc = msg->getHeader()->findField(fields::BCC);
+		msg->getHeader()->removeField(bcc);
+	}
+	catch (exceptions::no_such_field&) { }
+
 	// Generate the message, "stream" it and delegate the sending
 	// to the generic send() function.
 	std::ostringstream oss;
@@ -109,7 +123,7 @@ void transport::send(ref <vmime::message> msg, utility::progressListener* progre
 }
 
 
-const transport::Type transport::getType() const
+transport::Type transport::getType() const
 {
 	return (TYPE_TRANSPORT);
 }
