@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -70,14 +70,14 @@ void path::setDomain(const string& domain)
 }
 
 
-const bool path::operator==(const path& p) const
+bool path::operator==(const path& p) const
 {
 	return (m_localPart == p.m_localPart &&
 	        m_domain == p.m_domain);
 }
 
 
-const bool path::operator!=(const path& p) const
+bool path::operator!=(const path& p) const
 {
 	return (m_localPart != p.m_localPart ||
 	        m_domain != p.m_domain);
