@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -12,9 +12,13 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License along along
-// with this program; if not, write to the Free Software Foundation, Inc., Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
 #include "vmime/platforms/posix/posixChildProcess.hpp"
@@ -141,7 +145,7 @@ public:
 	{
 	}
 
-	const bool eof() const
+	bool eof() const
 	{
 		return (m_eof);
 	}
@@ -151,7 +155,7 @@ public:
 		// Do nothing: unsupported
 	}
 
-	const size_type skip(const size_type count)
+	size_type skip(const size_type count)
 	{
 		// TODO: not tested
 		value_type buffer[4096];
@@ -174,7 +178,7 @@ public:
 		return static_cast <size_type>(bytesSkipped);
 	}
 
-	const size_type read(value_type* const data, const size_type count)
+	size_type read(value_type* const data, const size_type count)
 	{
 		int bytesRead = 0;
 
