@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -50,6 +50,8 @@
 
 #include "vmime/security/digest/md5/md5MessageDigest.hpp"
 
+#include <cstring>
+
 
 namespace vmime {
 namespace security {
@@ -327,7 +329,7 @@ void md5MessageDigest::transform()
 }
 
 
-const int md5MessageDigest::getDigestLength() const
+int md5MessageDigest::getDigestLength() const
 {
 	return 16;
 }
