@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -94,8 +94,8 @@ void streamContentHandler::generate(utility::outputStream& os, const vmime::enco
 		// buffer, and then re-encode to output stream...
 		if (m_encoding != enc)
 		{
-			ref <encoder> theDecoder = m_encoding.getEncoder();
-			ref <encoder> theEncoder = enc.getEncoder();
+			ref <utility::encoder::encoder> theDecoder = m_encoding.getEncoder();
+			ref <utility::encoder::encoder> theEncoder = enc.getEncoder();
 
 			theEncoder->getProperties()["maxlinelength"] = maxLineLength;
 
@@ -122,7 +122,7 @@ void streamContentHandler::generate(utility::outputStream& os, const vmime::enco
 	// Need to encode data before
 	else
 	{
-		ref <encoder> theEncoder = enc.getEncoder();
+		ref <utility::encoder::encoder> theEncoder = enc.getEncoder();
 		theEncoder->getProperties()["maxlinelength"] = maxLineLength;
 
 		m_stream->reset();  // may not work...
@@ -151,7 +151,7 @@ void streamContentHandler::extract(utility::outputStream& os,
 	// Need to decode data
 	else
 	{
-		ref <encoder> theDecoder = m_encoding.getEncoder();
+		ref <utility::encoder::encoder> theDecoder = m_encoding.getEncoder();
 
 		m_stream->reset();  // may not work...
 
@@ -177,19 +177,19 @@ void streamContentHandler::extractRaw(utility::outputStream& os,
 }
 
 
-const string::size_type streamContentHandler::getLength() const
+string::size_type streamContentHandler::getLength() const
 {
 	return (m_length);
 }
 
 
-const bool streamContentHandler::isEmpty() const
+bool streamContentHandler::isEmpty() const
 {
 	return (m_length == 0 || !m_stream);
 }
 
 
-const bool streamContentHandler::isEncoded() const
+bool streamContentHandler::isEncoded() const
 {
 	return (m_encoding != NO_ENCODING);
 }
