@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -12,9 +12,13 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License along along
-// with this program; if not, write to the Free Software Foundation, Inc., Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
 #include "vmime/utility/datetimeUtils.hpp"
@@ -202,14 +206,14 @@ const datetime datetimeUtils::toLocalTime(const datetime& date, const int zone)
 }
 
 
-const bool datetimeUtils::isLeapYear(const int year)
+bool datetimeUtils::isLeapYear(const int year)
 {
 	// From RFC 3339 - Appendix C. Leap Years:
 	return ((year % 4) == 0 && (year % 100 != 0 || year % 400 == 0));
 }
 
 
-const int datetimeUtils::getDaysInMonth(const int year, const int month)
+int datetimeUtils::getDaysInMonth(const int year, const int month)
 {
 	static const int daysInMonth[12] =
 		{ 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
@@ -223,7 +227,7 @@ const int datetimeUtils::getDaysInMonth(const int year, const int month)
 }
 
 
-const int datetimeUtils::getDayOfWeek(const int year, const int month, const int day)
+int datetimeUtils::getDayOfWeek(const int year, const int month, const int day)
 {
 	int y = year;
 	int m = month;
@@ -252,7 +256,7 @@ const int datetimeUtils::getDayOfWeek(const int year, const int month, const int
 }
 
 
-const int datetimeUtils::getWeekOfYear(const int year, const int month, const int day)
+int datetimeUtils::getWeekOfYear(const int year, const int month, const int day)
 {
 	// Algorithm from http://personal.ecu.edu/mccartyr/ISOwdALG.txt
 
