@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -12,9 +12,13 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 // General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License along along
-// with this program; if not, write to the Free Software Foundation, Inc., Foundation, Inc.,
-// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA..
+// You should have received a copy of the GNU General Public License along
+// with this program; if not, write to the Free Software Foundation, Inc.,
+// 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+//
+// Linking this library statically or dynamically with other modules is making
+// a combined work based on this library.  Thus, the terms and conditions of
+// the GNU General Public License cover the whole combination.
 //
 
 #include "vmime/utility/filteredStream.hpp"
@@ -40,7 +44,7 @@ inputStream& dotFilteredInputStream::getPreviousInputStream()
 }
 
 
-const bool dotFilteredInputStream::eof() const
+bool dotFilteredInputStream::eof() const
 {
 	return (m_stream.eof());
 }
@@ -55,7 +59,7 @@ void dotFilteredInputStream::reset()
 }
 
 
-const stream::size_type dotFilteredInputStream::read(value_type* const data, const size_type count)
+stream::size_type dotFilteredInputStream::read(value_type* const data, const size_type count)
 {
 	const stream::size_type read = m_stream.read(data, count);
 
@@ -107,7 +111,7 @@ const stream::size_type dotFilteredInputStream::read(value_type* const data, con
 }
 
 
-const stream::size_type dotFilteredInputStream::skip(const size_type /* count */)
+stream::size_type dotFilteredInputStream::skip(const size_type /* count */)
 {
 	// Skipping bytes is not supported
 	return 0;
@@ -146,7 +150,7 @@ void dotFilteredOutputStream::write
 
 		if (previousChar == '\n')
 		{
-			m_stream.write(start, pos - data);
+			m_stream.write(start, pos - start);
 			m_stream.write("..", 2);
 
 			start = pos + 1;
@@ -246,7 +250,7 @@ void CRLFToLFFilteredOutputStream::flush()
 // stopSequenceFilteredInputStream <1>
 
 template <>
-const stream::size_type stopSequenceFilteredInputStream <1>::read
+stream::size_type stopSequenceFilteredInputStream <1>::read
 	(value_type* const data, const size_type count)
 {
 	if (eof() || m_stream.eof())
