@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -37,7 +37,7 @@ progressListenerSizeAdapter::progressListenerSizeAdapter
 }
 
 
-const bool progressListenerSizeAdapter::cancel() const
+bool progressListenerSizeAdapter::cancel() const
 {
 	return (m_wrapped ? m_wrapped->cancel() : false);
 }
