@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -44,8 +44,8 @@ VMIME_TEST_SUITE_BEGIN
 
 	struct A : public vmime::object
 	{
-		const int strongCount() const { return getRefManager()->getStrongRefCount(); }
-		const int weakCount() const { return getRefManager()->getWeakRefCount(); }
+		int strongCount() const { return getRefManager()->getStrongRefCount(); }
+		int weakCount() const { return getRefManager()->getWeakRefCount(); }
 	};
 
 	struct B : public virtual A { };
