@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -117,13 +117,13 @@ public:
 	  *
 	  * @return number of addresses
 	  */
-	const int getAddressCount() const;
+	int getAddressCount() const;
 
 	/** Tests whether the list of addresses is empty.
 	  *
 	  * @return true if there is no address, false otherwise
 	  */
-	const bool isEmpty() const;
+	bool isEmpty() const;
 
 	/** Return the address at the specified position.
 	  *
