@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -54,8 +54,8 @@ public:
 
 	charset& operator=(const charset& other);
 
-	const bool operator==(const charset& value) const;
-	const bool operator!=(const charset& value) const;
+	bool operator==(const charset& value) const;
+	bool operator!=(const charset& value) const;
 
 	const std::vector <ref <const component> > getChildComponents() const;
 
