@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -76,8 +76,8 @@ public:
 
 	messageId& operator=(const string& id);
 
-	const bool operator==(const messageId& mid) const;
-	const bool operator!=(const messageId& mid) const;
+	bool operator==(const messageId& mid) const;
+	bool operator!=(const messageId& mid) const;
 
 	/** Generate a random message identifier.
 	  *
