@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -31,6 +31,7 @@
 #include "vmime/net/socket.hpp"
 #include "vmime/net/folder.hpp"
 
+#include "vmime/net/maildir/maildirFormat.hpp"
 #include "vmime/net/maildir/maildirServiceInfos.hpp"
 
 #include "vmime/utility/file.hpp"
@@ -64,24 +65,27 @@ public:
 	ref <folder> getRootFolder();
 	ref <folder> getFolder(const folder::path& path);
 
-	const bool isValidFolderName(const folder::path::component& name) const;
+	bool isValidFolderName(const folder::path::component& name) const;
 
 	static const serviceInfos& getInfosInstance();
 	const serviceInfos& getInfos() const;
 
 	void connect();
-	const bool isConnected() const;
+	bool isConnected() const;
 	void disconnect();
 
 	void noop();
 
 	const utility::path& getFileSystemPath() const;
 
-	const int getCapabilities() const;
+	int getCapabilities() const;
 
-	const bool isSecuredConnection() const;
+	bool isSecuredConnection() const;
 	ref <connectionInfos> getConnectionInfos() const;
 
+	ref <maildirFormat> getFormat();
+	ref <const maildirFormat> getFormat() const;
+
 private:
 
 	void registerFolder(maildirFolder* folder);
@@ -90,6 +94,8 @@ private:
 
 	std::list <maildirFolder*> m_folders;
 
+	ref <maildirFormat> m_format;
+
 	bool m_connected;
 
 	utility::path m_fsPath;
