@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -50,7 +50,7 @@ public:
 	const ref <const contentHandler> getText() const;
 	void setText(ref <contentHandler> text);
 
-	const int getPartCount() const;
+	int getPartCount() const;
 
 	void generateIn(ref <bodyPart> message, ref <bodyPart> parent) const;
 	void parse(ref <const bodyPart> message, ref <const bodyPart> parent, ref <const bodyPart> textPart);
