@@ -1,6 +1,6 @@
 //
 // VMime library (http://vmime.sourceforge.net)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -49,7 +49,7 @@ public:
 	windowsHandler();
 	~windowsHandler();
 
-	const unsigned int getUnixTime() const;
+	unsigned int getUnixTime() const;
 
 	const vmime::datetime getCurrentLocalTime() const;
 
@@ -57,7 +57,7 @@ public:
 
 	const vmime::string getHostName() const;
 
-	const unsigned int getProcessId() const;
+	unsigned int getProcessId() const;
 
 #if VMIME_HAVE_MESSAGING_FEATURES
 	ref <vmime::net::socketFactory> getSocketFactory() const;
