@@ -1,6 +1,6 @@
 //
 // VMime library (http://vmime.sourceforge.net)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -46,11 +46,11 @@ public:
 public:
 
 	void connect(const vmime::string& address, const vmime::port_t port);
-	const bool isConnected() const;
+	bool isConnected() const;
 	void disconnect();
 
 	void receive(vmime::string& buffer);
-	const int receiveRaw(char* buffer, const int count);
+	int receiveRaw(char* buffer, const int count);
 
 	void send(const vmime::string& buffer);
 	void sendRaw(const char* buffer, const int count);
