@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -53,7 +53,7 @@ public:
 	  *
 	  * @return number of certificates in the chain
 	  */
-	const unsigned int getCount() const;
+	unsigned int getCount() const;
 
 	/** Return the certificate at the specified position. 0 is the
 	  * subject certificate, 1 is the issuer's certificate, 2 is
