@@ -1,6 +1,6 @@
 //
 // VMime library (http://www.vmime.org)
-// Copyright (C) 2002-2006 Vincent Richard <vincent@vincent-richard.net>
+// Copyright (C) 2002-2008 Vincent Richard <vincent@vincent-richard.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -87,7 +87,7 @@ public:
 	  *
 	  * @return number of body parts
 	  */
-	virtual const int getPartCount() const = 0;
+	virtual int getPartCount() const = 0;
 
 	/** Generate the text part(s) into the specified message.
 	  *
